@@ -1,9 +1,9 @@
 #' @describeIn userRoleAssignmentMethods Import user-role assignments to a project.
-#' @order 2   
+#' @order 2
 #' @export
 
-importUserRoleAssignments <- function(rcon, 
-                                      data, 
+importUserRoleAssignments <- function(rcon,
+                                      data,
                                       ...){
   UseMethod("importUserRoleAssignments")
 }
@@ -12,63 +12,63 @@ importUserRoleAssignments <- function(rcon,
 #' @order 4
 #' @export
 
-importUserRoleAssignments.redcapApiConnection <- function(rcon, 
-                                                          data, 
+importUserRoleAssignments.redcapApiConnection <- function(rcon,
+                                                          data,
                                                           ...)
 {
   ###################################################################
   # Argument Validation                                          ####
-  
+
   coll <- checkmate::makeAssertCollection()
-  
-  checkmate::assert_class(x = rcon, 
-                          classes = "redcapApiConnection", 
+
+  checkmate::assert_class(x = rcon,
+                          classes = "redcapApiConnection",
                           add = coll)
-  
-  checkmate::assert_data_frame(x = data, 
-                               col.names = "named", 
+
+  checkmate::assert_data_frame(x = data,
+                               col.names = "named",
                                add = coll)
 
   checkmate::reportAssertions(coll)
-  
-  
-  
-  checkmate::assert_subset(x = names(data), 
-                           choices = c("username", "unique_role_name"), 
+
+
+
+  checkmate::assert_subset(x = names(data),
+                           choices = names(redcapUserRoleAssignmentStructure(rcon$version())),
                            add = coll)
-  
+
   checkmate::reportAssertions(coll)
-  
-  
-  
-  checkmate::assert_subset(x = data$username, 
-                           choices = rcon$users()$username, 
+
+
+
+  checkmate::assert_subset(x = data$username,
+                           choices = rcon$users()$username,
                            add = coll)
-  
-  checkmate::assert_subset(x = data$unique_role_name, 
+
+  checkmate::assert_subset(x = data$unique_role_name,
                            choices = c(NA_character_, rcon$user_roles()$unique_role_name),
                            add = coll)
-  
+
   checkmate::reportAssertions(coll)
-  
-  
+
+
   n_username <- table(data$username)
   repeated_username <- n_username[which(n_username > 1)]
-  
+
   if (length(repeated_username) > 0){
-    coll$push(sprintf("Each username may only be listed once. Check %s", 
+    coll$push(sprintf("Each username may only be listed once. Check %s",
                       paste0(names(repeated_username), collapse = ", ")))
   }
-  
+
   checkmate::reportAssertions(coll)
-  
+
   ###################################################################
   # API Body List                                                ####
-  
-  body <- list(content = "userRoleMapping", 
-               action = "import", 
-               format = "csv", 
-               returnFormat = "csv", 
+
+  body <- list(content = "userRoleMapping",
+               action = "import",
+               format = "csv",
+               returnFormat = "csv",
                data = writeDataForImport(data))
 
   ###################################################################
