@@ -1,12 +1,10 @@
-context("export/import/delete Files Functionality")
-
 local_file <- test_path("testdata", "FileForImportExportTesting.txt")
 
 test_that(
   "import, export, and delete a file in a longitudinal project",
   {
     local_reproducible_output(width = 200)
-    
+
     expect_true(
       importFiles(rcon,
                   file = local_file,
@@ -27,7 +25,7 @@ test_that(
                            event = "event_1_arm_1",
                            dir = temp_dir,
                            file_prefix = TRUE)
-    expect_true(grepl(".+1-event_1_arm_1-FileForImportExportTesting.txt", 
+    expect_true(grepl(".+1-event_1_arm_1-FileForImportExportTesting.txt",
                       save_to))
 
     # And now import it again with an overwrite
@@ -96,9 +94,9 @@ test_that(
 
 
     temp_dir <- tempdir()
-    
+
     local_reproducible_output(width = 200)
-   
+
     expect_error(exportFiles(rcon,
                              record = "1",
                              field = "file_upload_test",
@@ -106,7 +104,7 @@ test_that(
                              repeat_instance = 1,
                              dir = temp_dir,
                              file_prefix = TRUE,
-                             config = list(1)), 
+                             config = list(1)),
                  "'config': Must have names")
     expect_error(exportFiles(rcon,
                              record = "1",
@@ -114,18 +112,18 @@ test_that(
                              event = "event_1_arm_1",
                              repeat_instance = 1,
                              dir = temp_dir,
-                             file_prefix = TRUE, 
-                             config = "not a list"), 
+                             file_prefix = TRUE,
+                             config = "not a list"),
                  "'config': Must be of type 'list'")
-    
+
     expect_error(exportFiles(rcon,
                              record = "1",
                              field = "file_upload_test",
                              event = "event_1_arm_1",
                              repeat_instance = 1,
                              dir = temp_dir,
-                             file_prefix = TRUE, 
-                             api_param = list(1)), 
+                             file_prefix = TRUE,
+                             api_param = list(1)),
                  "'api_param': Must have names")
     expect_error(exportFiles(rcon,
                              record = "1",
@@ -134,7 +132,7 @@ test_that(
                              repeat_instance = 1,
                              dir = temp_dir,
                              file_prefix = TRUE,
-                             api_param = "not a list"), 
+                             api_param = "not a list"),
                  "'api_param': Must be of type 'list'")
 
     # Export the file
@@ -146,10 +144,10 @@ test_that(
                            dir = temp_dir,
                            file_prefix = TRUE)
     expect_true(
-      grepl(".+1-event_1_arm_1-FileForImportExportTesting.txt", 
+      grepl(".+1-event_1_arm_1-FileForImportExportTesting.txt",
             save_to)
     )
-    
+
     local_reproducible_output(width = 200)
 
     expect_error(importFiles(rcon,
@@ -159,7 +157,7 @@ test_that(
                              event = "event_1_arm_1",
                              overwrite = TRUE,
                              repeat_instance = 1,
-                             config = list(1)), 
+                             config = list(1)),
                  "'config': Must have names")
     expect_error(importFiles(rcon,
                              file = local_file,
@@ -168,9 +166,9 @@ test_that(
                              event = "event_1_arm_1",
                              overwrite = TRUE,
                              repeat_instance = 1,
-                             config = "not a list"), 
+                             config = "not a list"),
                  "'config': Must be of type 'list'")
-    
+
     expect_error(importFiles(rcon,
                              file = local_file,
                              record = "1",
@@ -178,7 +176,7 @@ test_that(
                              event = "event_1_arm_1",
                              overwrite = TRUE,
                              repeat_instance = 1,
-                             api_param = list(1)), 
+                             api_param = list(1)),
                  "'api_param': Must have names")
     expect_error(importFiles(rcon,
                              file = local_file,
@@ -187,7 +185,7 @@ test_that(
                              event = "event_1_arm_1",
                              overwrite = TRUE,
                              repeat_instance = 1,
-                             api_param = "not a list"), 
+                             api_param = "not a list"),
                  "'api_param': Must be of type 'list'")
 
     # And now import it again with an overwrite
@@ -214,36 +212,36 @@ test_that(
     )
 
     local_reproducible_output(width = 200)
-    expect_error(deleteFiles(rcon, 
-                             record = "1",
-                             field = "file_upload_test",
-                             event = "event_1_arm_1",
-                             repeat_instance = 1, 
-                             config = list(1)), 
-                 "'config': Must have names")
-    expect_error(deleteFiles(rcon, 
-                             record = "1",
-                             field = "file_upload_test",
-                             event = "event_1_arm_1",
-                             repeat_instance = 1, 
-                             config = "not a list"), 
-                 "'config': Must be of type 'list'")
-    
-    expect_error(deleteFiles(rcon, 
-                             record = "1",
-                             field = "file_upload_test",
-                             event = "event_1_arm_1",
-                             repeat_instance = 1, 
-                             api_param = list(1)), 
-                 "'api_param': Must have names")
-    expect_error(deleteFiles(rcon, 
+    expect_error(deleteFiles(rcon,
                              record = "1",
                              field = "file_upload_test",
                              event = "event_1_arm_1",
                              repeat_instance = 1,
-                             api_param = "not a list"), 
+                             config = list(1)),
+                 "'config': Must have names")
+    expect_error(deleteFiles(rcon,
+                             record = "1",
+                             field = "file_upload_test",
+                             event = "event_1_arm_1",
+                             repeat_instance = 1,
+                             config = "not a list"),
+                 "'config': Must be of type 'list'")
+
+    expect_error(deleteFiles(rcon,
+                             record = "1",
+                             field = "file_upload_test",
+                             event = "event_1_arm_1",
+                             repeat_instance = 1,
+                             api_param = list(1)),
+                 "'api_param': Must have names")
+    expect_error(deleteFiles(rcon,
+                             record = "1",
+                             field = "file_upload_test",
+                             event = "event_1_arm_1",
+                             repeat_instance = 1,
+                             api_param = "not a list"),
                  "'api_param': Must be of type 'list'")
-    
+
     # Delete the file
     expect_true(
       deleteFiles(rcon,
@@ -252,65 +250,65 @@ test_that(
                   event = "event_1_arm_1",
                   repeat_instance = 1)
     )
-    
-    lapply(list.files(temp_dir), 
+
+    lapply(list.files(temp_dir),
            unlink)
   }
 )
 
 test_that(
-  "Files imported/exported from repeat instances > 1", 
+  "Files imported/exported from repeat instances > 1",
   {
     temp_file <- tempfile(fileext = ".txt")
     file.copy(local_file, temp_file)
-    
-    expect_true(importFiles(rcon, 
-                            file = local_file, 
-                            record = "1", 
-                            field = "file_upload_test", 
-                            event = "event_1_arm_1", 
+
+    expect_true(importFiles(rcon,
+                            file = local_file,
+                            record = "1",
+                            field = "file_upload_test",
+                            event = "event_1_arm_1",
                             repeat_instance = 1))
-    
-    expect_true(importFiles(rcon, 
-                            file = temp_file, 
-                            record = "1", 
-                            field = "file_upload_test", 
-                            event = "event_1_arm_1", 
+
+    expect_true(importFiles(rcon,
+                            file = temp_file,
+                            record = "1",
+                            field = "file_upload_test",
+                            event = "event_1_arm_1",
                             repeat_instance = 2))
-    
+
     target_dir <- tempdir()
-    
-    file1 <- exportFiles(rcon, 
-                         record = "1", 
-                         field = "file_upload_test", 
-                         event = "event_1_arm_1", 
-                         dir = target_dir, 
+
+    file1 <- exportFiles(rcon,
+                         record = "1",
+                         field = "file_upload_test",
+                         event = "event_1_arm_1",
+                         dir = target_dir,
                          repeat_instance = 1)
     expect_true(file.exists(file1))
     expect_true(grepl("FileForImportExportTesting.txt", file1))
-    
-    file2 <- exportFiles(rcon, 
-                         record = "1", 
-                         field = "file_upload_test", 
-                         event = "event_1_arm_1", 
-                         dir = target_dir, 
+
+    file2 <- exportFiles(rcon,
+                         record = "1",
+                         field = "file_upload_test",
+                         event = "event_1_arm_1",
+                         dir = target_dir,
                          repeat_instance = 2)
-    
+
     expect_true(file.exists(file2))
     expect_true(grepl(basename(temp_file), file2))
-    
-    expect_true(deleteFiles(rcon, 
-                            record = "1", 
-                            field = "file_upload_test", 
-                            event = "event_1_arm_1", 
+
+    expect_true(deleteFiles(rcon,
+                            record = "1",
+                            field = "file_upload_test",
+                            event = "event_1_arm_1",
                             repeat_instance = 1))
-    
-    expect_true(deleteFiles(rcon, 
-                            record = "1", 
-                            field = "file_upload_test", 
-                            event = "event_1_arm_1", 
+
+    expect_true(deleteFiles(rcon,
+                            record = "1",
+                            field = "file_upload_test",
+                            event = "event_1_arm_1",
                             repeat_instance = 2))
-    
+
     # clean up
     unlink(temp_file)
   }
